@@ -89,12 +89,19 @@ metrics_graph2pajek = Summary("fix_graph2pajek_seconds", "Time it took the graph
 EdgeKey = namedtuple("EdgeKey", ["src", "dst", "edge_type"])
 
 
+class MaxNodesExceeded(ValueError):
+    pass
+
+
 class Graph(networkx.MultiDiGraph):  # type: ignore
     """A directed Graph"""
 
-    def __init__(self, *args: Any, root: Optional[BaseResource] = None, **kwargs: Any) -> None:
+    def __init__(
+        self, *args: Any, root: Optional[BaseResource] = None, max_nodes: Optional[int] = None, **kwargs: Any
+    ) -> None:
         super().__init__(*args, **kwargs)
         self.root = None
+        self.max_nodes = max_nodes
         self._log_edge_creation = True
         if isinstance(root, BaseResource):
             self.root = root
@@ -152,6 +159,8 @@ class Graph(networkx.MultiDiGraph):  # type: ignore
         self.add_edge(src=parent, dst=node_for_adding, edge_type=edge_type)
 
     def add_node(self, node_for_adding: BaseResource, **attr: Any) -> None:
+        if self.max_nodes is not None and len(self.nodes()) >= self.max_nodes:
+            raise MaxNodesExceeded(f"Graph has reached maximum number of nodes ({self.max_nodes})")
         super().add_node(node_for_adding, **attr)
         if isinstance(node_for_adding, BaseResource):
             # We hand a reference to ourselves to the added BaseResource
@@ -282,21 +291,19 @@ class Graph(networkx.MultiDiGraph):  # type: ignore
     @metrics_graph_search.time()
     def search(self, attr: str, value: Any, regex_search: bool = False) -> Iterator[BaseResource]:
         """Search for graph nodes by their attribute value"""
-        if value is None:
-            log.debug(f"Not searching graph for nodes with attribute values {attr}: {value}")
-            return ()
-        log.debug((f"Searching graph for nodes with attribute values {attr}: {value}" f" (regex: {regex_search})"))
-        for node in self.nodes():
-            node_attr = getattr(node, attr, None)
-            if (
-                node_attr is not None
-                and not callable(node_attr)
-                and (
-                    (regex_search is False and node_attr == value)
-                    or (regex_search is True and re.search(value, str(node_attr)))
-                )
-            ):
-                yield node
+        if value is not None:
+            log.debug(f"Searching graph for nodes with attribute values {attr}: {value}" f" (regex: {regex_search})")
+            for node in self.nodes():
+                node_attr = getattr(node, attr, None)
+                if (
+                    node_attr is not None
+                    and not callable(node_attr)
+                    and (
+                        (regex_search is False and node_attr == value)
+                        or (regex_search is True and re.search(value, str(node_attr)))
+                    )
+                ):
+                    yield node
 
     @metrics_graph_searchre.time()
     def searchre(self, attr: str, regex: str) -> Iterator[BaseResource]:
